instance get more than one fixed ip(grizzly-g3) - Ask OpenStack: Q&A Site for OpenStack Users and Developers
Description: i have install grizzly-g3, but quantum does not work well, when i boot 128 instances, i found one of instances got more than one fixed ip, howerver, when i boot 64 intances, it nerver happened, besides that , sometimes i can not ping vm with floatingip, i did not find any error message in my quantum log( all the files in the /var/log/quantum), follows are the error output and configurations | 97a93600-38e2-4700-9851-15ef56c1d628 | slave | ACTIVE | demo-int-net=172.16.100.4 | | 99aeb6b8-4252-4839-a7d1-f87853116100 | slave | ACTIVE | demo-int-net=172.16.100.117 | | 9aa82a35-c9f1-4f44-a108-d14e74eec231 | slave | ACTIVE | demo-int-net=172.16.100.108, 172.16.100.109 | | 9b6b1289-c450-4614-b647-e5ebdffff80a | slave | ACTIVE | demo-int-net=172.16.100.5 | | 9e0d3aa5-0f15-4b24-944a-6d6c3e18ce64 | slave | ACTIVE | demo-int-net=172.16.100.35 | | 9ea62124-9128-43cc-acdd-142f1e7743d6 | slave | ACTIVE | demo-int-net=172.16.100.132 | my setup : one db host(db service), one glance host(glance service) [cell cut: 3773 characters, first 1000 kept]
Keywords: ,Ask, OpenStack,forum,community,cloud,iaas

First time here? Check out the FAQ!

English ▼
Hi there! Please sign in tags users badges help

| ALL UNANSWERED |  | Ask Your Question

1

# instance get more than one fixed ip(grizzly-g3)

- neutron
- migrated

asked 2013-03-26 01:09:38 -0600

xinxin-shu
11 ●1 ●2 ●3

i have install grizzly-g3, but quantum does not work well, when i boot 128 instances, i found one of instances got more than one fixed ip, howerver, when i boot 64 intances, it nerver happened, besides that , sometimes i can not ping vm with floatingip, i did not find any error message in my quantum log( all the files in the /var/log/quantum), follows are the error output and configurations

| 97a93600-38e2-4700-9851-15ef56c1d628 | slave | ACTIVE | demo-int-net=172.16.100.4 | | 99aeb6b8-4252-4839-a7d1-f87853116100 | slave | ACTIVE | demo-int-net=172.16.100.117 | | 9aa82a35-c9f1-4f44-a108-d14e74eec231 | slave | ACTIVE | demo-int-net=172.16.100.108, 172.16.100.109 | | 9b6b1289-c450-4614-b647-e5ebdffff80a | slave | ACTIVE | demo-int-net=172.16.100.5 | | 9e0d3aa5-0f15-4b24-944a-6d6c3e18ce64 | slave | ACTIVE | demo-int-net=172.16.100.35 | | 9ea62124-9128-43cc-acdd-142f1e7743d6 | slave | ACTIVE | demo-int-net=172.16.100.132 |

my setup : one db host(db service), one glance host(glance service), on api host(keystone,nova-api,nova-scheduler, nova-conductor, quantum-server,quantum-dhcp, quantum-l3-agent,quantum-plugin-openvswitch-agent), eight compute host(each host with nova-compute, quantum-plugin-openvswitch-agent), i check that all the service on all hosts works well

i used vlan type network and openvswitch plugin:

my quantum.conf

[DEFAULT]

# Default log level is INFO

# verbose and debug has the same result.

# One of them will set DEBUG log level output

debug = True

# Address to bind the API server

bind_host = 0.0.0.0

# Port the bind the API server to

bind_port = 9696

# Quantum plugin provider module

# core_plugin =

core_plugin = quantum.plugins.openvswitch.ovs_quantum_plugin.OVSQuantumPluginV2

# Advanced service modules

# service_plugins =

# Paste configuration file

api_paste_config = /etc/quantum/api-paste.ini

# The strategy to be used for auth.

# Supported values are 'keystone'(default), 'noauth'.

auth_strategy = keystone

# Modules of exceptions that are permitted to be recreated

# upon receiving exception data from an rpc call.

# allowed_rpc_exception_modules = quantum.openstack.common.exception, nova.exception

# AMQP exchange to connect to if using RabbitMQ or QPID

control_exchange = quantum

# RPC driver. DHCP agents needs it.

notification_driver = quantum.openstack.common.notifier.rpc_notifier

# default_notification_level is used to form actual topic name(s) or to set logging level

default_notification_level = INFO

# Defined in rpc_notifier, can be comma separated values.

# The actual topic names will be %s.%(default_notification_level)s

notification_topics = notifications

[QUOTAS]

# resource name(s) that are supported in quota features

# quota_items = network,subnet,port

# default number of resource allowed per tenant, minus for unlimited

# default_quota = -1

# number of networks allowed per tenant, and minus means unlimited

# quota_network = 10

# number of subnets allowed per tenant, and minus means unlimited

# quota_subnet = 10

# number of ports allowed per tenant, and minus means unlimited

quota_port = 5000 quota_floatingip = 5000

# default driver to use for quota checks

# quota_driver = quantum.quota.ConfDriver

# =========== items for agent management extension =============

# Seconds to regard the agent as down.

# agent_down_time = 5

# =========== end of items for agent management extension =====

[DEFAULT_SERVICETYPE]

# Description of the default service type (optional)

# description = "default service type"

# Enter a service definition line for each advanced service provided

# by the default service type.

# Each service definition should be in the following format:

# <service>:<plugin>[:driver]

[SECURITYGROUP]

# If set to true this allows quantum to receive proxied security group calls from nova

# proxy_mode = False

[AGENT] root_helper = sudo quantum-rootwrap /etc/quantum ... (more)

edit retag flag offensive close merge delete
add a comment

## 31 answers

Sort by » oldest newest most voted
« previous 1...1 2 3 4...4 next »
0

answered 2013-03-26 01:15:45 -0600

xinxin-shu
11 ●1 ●2 ●3

ovs-vsctl show on api host

fa0399c8-2abc-4161-8a7c-18b7404f1836 Bridge br-ex Port br-ex Interface br-ex type: internal Port "qg-28ba8355-4c" Interface "qg-28ba8355-4c" type: internal Port "eth2" Interface "eth2" Bridge br-int Port "qr-a69d9f83-ff" tag: 1 Interface "qr-a69d9f83-ff" type: internal Port int-DemoBridge Interface int-DemoBridge Port "tap9d3ab4cf-59" tag: 1 Interface "tap9d3ab4cf-59" type: internal Port br-int Interface br-int type: internal Bridge DemoBridge Port "eth1" Interface "eth1" Port phy-DemoBridge Interface phy-DemoBridge Port DemoBridge Interface DemoBridge type: internal ovs_version: "1.4.3"

ovs-vsctl show on compute host

Bridge br-int Port "tapc6ab6692-92" tag: 1 Interface "tapc6ab6692-92" Port "tapdd3bbb21-1a" tag: 1 Interface "tapdd3bbb21-1a" Bridge DemoBridge Port "bond0" Interface "bond0" Port phy-DemoBridge Interface phy-DemoBridge Port DemoBridge Interface DemoBridge type: internal ovs_version: "1.4.3"

edit flag offensive delete link more
add a comment
« previous 1...1 2 3 4...4 next »

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]

# Get to know Ask OpenStack

Resources for moderators

## Question Tools

1 follower

## Stats

Asked: 2013-03-26 01:09:38 -0600

Seen: 232 times

Last updated: Jul 03 '13

## Related questions

A question about ovs-vlan-test

can't ping floating ip

about l3 agent

noVNC support for Google Chrome 14+

[mitaka][octavia] octavia-worker cannot reach amphora [closed]

what's the _junk in codes?

unable to assign floating ip to instance

Connecting OVS interfaces to a bond with VLAN tagging

neutron router iptables not hit

Howto Multiserver Stats

( 2016-11-08 11:32:39 -0600 )edit
none